==> openshift-model-hive-5.12.1-sources.jar: io/fabric8/openshift/api/model/hive/v1/ControllerConfigBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ControllerConfigBuilder extends io.fabric8.openshift.api.model.hive.v1.ControllerConfigFluentImpl<io.fabric8.openshift.api.model.hive.v1.ControllerConfigBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.hive.v1.ControllerConfig,io.fabric8.openshift.api.model.hive.v1.ControllerConfigBuilder>{
  public ControllerConfigBuilder() {
    this(false);
  }
  public ControllerConfigBuilder(java.lang.Boolean validationEnabled) {
    this(new ControllerConfig(), validationEnabled);
  }
  public ControllerConfigBuilder(io.fabric8.openshift.api.model.hive.v1.ControllerConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public ControllerConfigBuilder(io.fabric8.openshift.api.model.hive.v1.ControllerConfigFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ControllerConfig(), validationEnabled);
  }
  public ControllerConfigBuilder(io.fabric8.openshift.api.model.hive.v1.ControllerConfigFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.ControllerConfig instance) {
    this(fluent, instance, false);
  }
  public ControllerConfigBuilder(io.fabric8.openshift.api.model.hive.v1.ControllerConfigFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.ControllerConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withClientBurst(instance.getClientBurst()); 
    fluent.withClientQPS(instance.getClientQPS()); 
    fluent.withConcurrentReconciles(instance.getConcurrentReconciles()); 
    fluent.withQueueBurst(instance.getQueueBurst()); 
    fluent.withQueueQPS(instance.getQueueQPS()); 
    fluent.withReplicas(instance.getReplicas()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ControllerConfigBuilder(io.fabric8.openshift.api.model.hive.v1.ControllerConfig instance) {
    this(instance,false);
  }
  public ControllerConfigBuilder(io.fabric8.openshift.api.model.hive.v1.ControllerConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withClientBurst(instance.getClientBurst()); 
    this.withClientQPS(instance.getClientQPS()); 
    this.withConcurrentReconciles(instance.getConcurrentReconciles()); 
    this.withQueueBurst(instance.getQueueBurst()); 
    this.withQueueQPS(instance.getQueueQPS()); 
    this.withReplicas(instance.getReplicas()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.hive.v1.ControllerConfigFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.hive.v1.ControllerConfig build() {
    ControllerConfig buildable = new ControllerConfig(fluent.getClientBurst(),fluent.getClientQPS(),fluent.getConcurrentReconciles(),fluent.getQueueBurst(),fluent.getQueueQPS(),fluent.getReplicas());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ControllerConfigBuilder that = (ControllerConfigBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-hive-6.5.1-sources.jar: io/fabric8/openshift/api/model/hive/v1/ControllerConfigBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ControllerConfigBuilder extends ControllerConfigFluentImpl<ControllerConfigBuilder> implements VisitableBuilder<ControllerConfig,ControllerConfigBuilder>{
  public ControllerConfigBuilder() {
    this(false);
  }
  public ControllerConfigBuilder(Boolean validationEnabled) {
    this(new ControllerConfig(), validationEnabled);
  }
  public ControllerConfigBuilder(ControllerConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public ControllerConfigBuilder(ControllerConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ControllerConfig(), validationEnabled);
  }
  public ControllerConfigBuilder(ControllerConfigFluent<?> fluent,ControllerConfig instance) {
    this(fluent, instance, false);
  }
  public ControllerConfigBuilder(ControllerConfigFluent<?> fluent,ControllerConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withClientBurst(instance.getClientBurst()); 
    fluent.withClientQPS(instance.getClientQPS()); 
    fluent.withConcurrentReconciles(instance.getConcurrentReconciles()); 
    fluent.withQueueBurst(instance.getQueueBurst()); 
    fluent.withQueueQPS(instance.getQueueQPS()); 
    fluent.withReplicas(instance.getReplicas()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ControllerConfigBuilder(ControllerConfig instance) {
    this(instance,false);
  }
  public ControllerConfigBuilder(ControllerConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withClientBurst(instance.getClientBurst()); 
    this.withClientQPS(instance.getClientQPS()); 
    this.withConcurrentReconciles(instance.getConcurrentReconciles()); 
    this.withQueueBurst(instance.getQueueBurst()); 
    this.withQueueQPS(instance.getQueueQPS()); 
    this.withReplicas(instance.getReplicas()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ControllerConfigFluent<?> fluent;
  Boolean validationEnabled;
  public ControllerConfig build() {
    ControllerConfig buildable = new ControllerConfig(fluent.getClientBurst(),fluent.getClientQPS(),fluent.getConcurrentReconciles(),fluent.getQueueBurst(),fluent.getQueueQPS(),fluent.getReplicas());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
